from collections.abc import Generator

from _typeshed import Incomplete
from xmldiff import actions as actions

class Patcher:
    def patch(self, actions, tree): ...
    def handle_action(self, action, tree) -> None: ...

class DiffParser:
    def parse(self, diff) -> Generator[Incomplete, None, None]: ...
    def make_action(self, line): ...
